#
# spec file for package perl-Sereal-Encoder
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Sereal-Encoder
Version:        4.007
Release:        lp150.10.2
%define cpan_name Sereal-Encoder
Summary:        Binary serialization module for Perl (encoder part)
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/Y/YV/YVES/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(ExtUtils::ParseXS) >= 2.21
BuildRequires:  perl(Sereal::Decoder) >= 4.002
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Differences)
BuildRequires:  perl(Test::LongString)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Warn)
%{perl_requires}

%description
This library implements an efficient, compact-output, and feature-rich
serializer using a binary protocol called _Sereal_. Its sister module
Sereal::Decoder implements a decoder for this format. The two are released
separately to allow for independent and safer upgrading. If you care
greatly about performance, consider reading the Sereal::Performance
documentation after finishing this document.

The Sereal protocol version emitted by this encoder implementation is
currently protocol version 4 by default.

The protocol specification and many other bits of documentation can be
found in the github repository. Right now, the specification is at
https://github.com/Sereal/Sereal/blob/master/sereal_spec.pod, there is a
discussion of the design objectives in
https://github.com/Sereal/Sereal/blob/master/README.pod, and the output of
our benchmarks can be seen at
https://github.com/Sereal/Sereal/wiki/Sereal-Comparison-Graphs. For more
information on getting the best performance out of Sereal, have a look at
the "PERFORMANCE" section below.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
# Don't build with smp_flags!
make

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes

%changelog
* Fri Aug 30 2019 Tina Mueller <tina.mueller@suse.com>
- Add custom_build in cpanspec.yml. make doesn't work here with -j...
* Wed Apr 10 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.007
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  4.007 Tues Apr 9, 2019
  * Version bump only
  4.006 Mon Apr 8, 2019
  * Version bump only
* Tue Apr  9 2019 Stephan Kulow <coolo@suse.com>
- updated to 4.006
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Mon Oct 22 2018 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of summary.
* Sun Oct  7 2018 Dirk Stoecker <opensuse@dstoecker.de>
- Fix autogenerated changes
* Wed Feb  7 2018 coolo@suse.com
- updated to 4.005
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Fri Sep  2 2016 coolo@suse.com
- updated to 3.015
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.015 Thu Sep  1 20:18:44 CEST 2016
  * Fix builds under 5.25+
* Wed Dec  9 2015 coolo@suse.com
- updated to 3.014
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.014 Dec  7 2015
  * Fix builds under 5.8.9
  3.012 Dec  6 2015
  * Yet another release related to broken META files.
    ExtUtils::MakeMaker and CPAN::Meta need to be up to date
    or the META files miss stuff.
  3.011 Dec  6 2015
  * No significant changes. Doc typo fixes, and build tweaks.
  3.010 Dec  1 2015
  * Build fixes.
* Wed Dec  2 2015 coolo@suse.com
- updated to 3.009
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.009 Nov 30 2015
  * Re-relase 3.008 with updated META files.
* Sat Nov 28 2015 coolo@suse.com
- updated to 3.008
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.008 Nov 27 2015
  * FIX: Make sure that reserializing a data structure created
    using alias_varint_under does not produce a corrupted dataset.
    Thanks to Iskra for the report.
  * FIX: Precedence issue related to sort keys options. Thanks
    to Petr Písař <ppisar@redhat.com> for the report and fix.
  * FIX: Win32 build issues, thanks to bulk88 for help.
  3.007 Nov 26 2015
  * FIX: sorting should now work with tied hashes, and
    be in general faster.
  * CHANGED: Sort order for sort_keys=1 is now defined to be
    "in order by length of bytes, then by byte order of the
    underlying string, then by utd8ness, with non-utf8 first".
    This sort order was chosen because it requires the least
    operations to perform in the most cases, has a bounded number
    of cases where we would have to create any temporary SV's or
    to do operations that require us to introspect codepoints in
    utf8 strings. IOW purely performance. Note that so long
    as you compare data created with the same sort_keys setting
    you will ALWAYS get the same order *in process*, regardless
    of what you choose. Backwards compatible support for  the
    old order is available via sort_keys=3.
    ADDED: sort_keys=2 to provide "perl cmp order"
    (Its just there because it is easy to do, not for any
    good reason.)
    ADDED: sort_keys=3 to provide "rev perl cmp order"
    Legacy sort order was equivalent to sort_keys=3, use this
    option *ONLY* if you are extremely sensitive to changes in the
    sorted order (or "canonical form").
  * [DECODER] Build fixes for boxes without any Sereal installed (it seems
    to be common on certain types of smokers, and not on others).
  * Fix issues with serializing blessed scalars where we see the
    blessed scalar before we see the reference to it.
  * Handle PVLV undefs
  * Build fixes for 5.8.9
  * Doc patches
  * Optimizations
* Sun Nov 15 2015 coolo@suse.com
- updated to 3.006
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
  3.006 Nov 14 2015
  * [DECODER] fix segfaults from heavily corrupted data. Guards
    against various pathological cases which could cause segfaults
    fixed. Thanks to Damian Gryski and "fuzzing sereal with afl"
    for finding these cases.
  * [ENCODER] Various subtle fixes to how we choose whether to serialize
    the string or numeric version of a value, in particular to
    ensure that "00" always round trips as "00", and related issues.
    Note this fix has correctness and performance consequences. In
    some cases values that used to serialized as integers (arguably
    incorrectly) will be serialized as strings instead, and some code
    maybe be slower to serialize.
    NOTE: Some issues related to this subject are not fixable without
    a protocol change. In particular this change may affect the behavior
    of code that uses binary logical operators on values serialized
    with Perl.
    Thanks to Zefram, Tom, and others for help with this issue.
  * Fixups for cast warnings under -Wint-to-ptr builds by using
    using PTR2INT and INT2PTR for casting our objects.
  * Win32 fixes
  * Build improvements
  * Changes to how we generate constants
* Tue Apr 14 2015 coolo@suse.com
- updated to 3.005
  see /usr/share/doc/packages/perl-Sereal-Encoder/Changes
* Fri Oct  4 2013 coolo@suse.com
- initial package 0.37
  * created by cpanspec 1.78.07
